package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.VipQuanyi;
import org.apache.ibatis.annotations.Param;

/**
 * quanyiMapper接口
 *
 * @author ruoyi
 * @date 2023-06-06
 */
public interface VipQuanyiMapper  extends BaseMapper<VipQuanyi>
{
    /**
     * 查询quanyi
     *
     * @param id quanyi主键
     * @return quanyi
     */
    public VipQuanyi selectVipQuanyiById(Long id);

    /**
     * 用户待领取的优惠券
     * @param userId
     * @param language
     * @return
     */
    public List<VipQuanyi> userUnclaimedList(@Param("userId") Long userId, @Param("language") String language, @Param("mdId") Long mdId);

    /**
     * 查询quanyi列表
     *
     * @param vipQuanyi quanyi
     * @return quanyi集合
     */
    public List<VipQuanyi> selectVipQuanyiList(VipQuanyi vipQuanyi);

    /**
     * 新增quanyi
     *
     * @param vipQuanyi quanyi
     * @return 结果
     */
    public int insertVipQuanyi(VipQuanyi vipQuanyi);

    /**
     * 修改quanyi
     *
     * @param vipQuanyi quanyi
     * @return 结果
     */
    public int updateVipQuanyi(VipQuanyi vipQuanyi);

    /**
     * 删除quanyi
     *
     * @param id quanyi主键
     * @return 结果
     */
    public int deleteVipQuanyiById(Long id);

    /**
     * 批量删除quanyi
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVipQuanyiByIds(Long[] ids);
}
